@@ -17,15 +17,15 @@ sepkoski <- sepkoski[which(sepkoski$PHYLUM == "Brachiopoda"),]
 brachios <- chrono_scale(brachios, srt = "early_interval", end = "late_interval",
                           max_ma = "max_ma", min_ma = "min_ma", verbose = FALSE)
 
-## ---- results='markup', message=TRUE------------------------------------------
+## ----results='markup', message=TRUE-------------------------------------------
 # combine the datasets
 occs <- cbind.data.frame(phylum = c(brachios$phylum, sepkoski$PHYLUM),
                          class = c(brachios$class, sepkoski$CLASS),
                          order = c(brachios$order, sepkoski$ORDER), 
                          family = c(brachios$family, rep(NA, nrow(sepkoski))),
                          genus = c(brachios$genus, sepkoski$GENUS),
-                         max_ma = c(brachios$newFAD, sepkoski$RANGE_BASE),
-                         min_ma = c(brachios$newLAD, sepkoski$RANGE_TOP),
+                         max_ma = c(brachios$max_ma, sepkoski$RANGE_BASE),
+                         min_ma = c(brachios$min_ma, sepkoski$RANGE_TOP),
                          coll_no = c(brachios$collection_no, rep(NA, nrow(sepkoski))))
 # define the taxonomic ranks used in the dataset (re-used elsewhere)
 b_ranks <- c("phylum", "class", "order", "family", "genus")
@@ -87,9 +87,11 @@ plot_dprofile(dens, "Atrypa")
 pacm <- pacmacro_ranges(brachios_c, tail.flag = c(0.3, 0.35, 0.4),
                         rank = "genus", srt = "max_ma", end = "min_ma")
 # replot the taxon and mark its truncated ranges
-plot_dprofile(dens, "Atrypa")
+op <- par()
+plot_dprofile(dens, "Atrypa", exit = FALSE)
 abline(v = pacm$kdensity["Atrypa","FAD95"], col = "blue")
 abline(v = pacm$kdensity["Atrypa","LAD95"], col = "blue")
+on.exit(par(op))
 
 ## -----------------------------------------------------------------------------
 # extract the truncated ranges
@@ -107,11 +109,11 @@ brachios_c$pflag <- pflags$occurrence$status
 
 ## -----------------------------------------------------------------------------
 # interpeak thresholding
-itp <- threshold_ranges(brachios_c, win = 8, thresh = 10,
+itp <- threshold_ranges(brachios_c, win = 10, thresh = 10,
                         rank = "genus", srt = "max_ma", end = "min_ma")
 # append the stratigraphically thresholded taxon names to the dataset
 brachios_c$newgen <- itp$data
 # plot the taxon, now identifying the peaks
-plot_dprofile(dens, "Atrypa")
+plot_dprofile(dens, "Atrypa", exit = FALSE)
 add_itp(itp, "Atrypa")
 
